Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type LeporaMode ¶
type LeporaMode string
var ( Managed LeporaMode = "managed" Self LeporaMode = "self" Matrix LeporaMode = "matrix" Local LeporaMode = "local" )
type LeporaOptions ¶
type LeporaOptions struct {
//the method of logging, local, managed, self-managed or matrix which is a combination of local and managed logging
Method LeporaMode
//the path to the log file
Path string
//the name of the log file
Name string
//the maximum size of the log file
MaxSize int
//the maximum number of log files
MaxFiles int
//the maximum number of days to keep the log files
MaxDays int
//debug mode on or off
Debug bool
//the level of logging
Level string
//should logs be persisted
Persist *bool
//AutoClean log files
AutoClean *bool
}
Click to show internal directories.
Click to hide internal directories.