package
Version:
v0.1.2
Opens a new window with list of versions in this module.
Published: Sep 22, 2022
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Log struct {
ID uint `gorm:"primaryKey"`
AppKey string `gorm:"type:varchar(255)"`
Logs string `gorm:"type:text"`
CreatedAt string `gorm:"type:varchar(255)"`
}
create log model for postgres database
create foreignkey for Appkey id in Log struct
Source Files
¶
Click to show internal directories.
Click to hide internal directories.