network

package
v0.1.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 22, 2022 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func PostLogs

func PostLogs(log string, network NetworkOptions) error

make a post request to server to send logs

Types

type NetworkOptions

type NetworkOptions struct {
	//URL for sending logs
	URL string
	//the access token to be used to send logs
	AccessToken string
	//app key
	AppKey string
}

Jump to